yt_cli library

CLI commands for the yt package.

Classes

AnalyticsReportsQueryCommand
Query YouTube Analytics reports with custom metrics and dimensions.
GroupItemsDeleteCommand
GroupItemsInsertCommand
GroupItemsListCommand
GroupsDeleteCommand
GroupsInsertCommand
GroupsListCommand
Retrieve a list of analytics groups for the authenticated user.
GroupsUpdateCommand
YoutubeActivitiesCommand
An activity resource contains information about an action that a particular channel, or user, has taken on YouTube.
YoutubeAddCommentsCommand
YoutubeAddCommentThreadsCommand
Helper method that creates a new top-level comment thread.
YoutubeAnalyticsCommand
Root command for YouTube Analytics operations.
YoutubeAnalyticsGroupItemsCommand
YoutubeAnalyticsGroupsCommand
Command group for managing YouTube Analytics groups.
YoutubeAnalyticsReportsCommand
Command group for querying YouTube Analytics reports.
YoutubeAuthorizeCommand
Generate a refresh token used to authenticate the command line API requests.
YoutubeBindBroadcastCommand
Binds a YouTube broadcast to a stream or removes an existing binding between a broadcast and a stream. A broadcast can only be bound to one video stream, though a video stream may be bound to more than one broadcast.
YoutubeBroadcastCommand
A liveBroadcast resource represents an event that will be streamed, via live video, on YouTube.
YoutubeCaptionsCommand
Command group for the captions resource.
YoutubeChangeCommentsCommand
YoutubeChannelBannersCommand
Command group for the channelBanners resource.
YoutubeChannelsCommand
A channel resource contains information about a YouTube channel.
YoutubeChannelSectionsCommand
Command group for the channelSections resource.
YoutubeCommentsCommand
A comment resource contains information about a single YouTube comment.
YoutubeCommentThreadsCommand
A commentThread resource contains information about a YouTube comment thread, which comprises a top-level comment and replies, if any exist, to that comment. A commentThread resource can represent comments about either a video or a channel.
YoutubeDeleteBroadcastCommand
Deletes a broadcast.
YoutubeDeleteCaptionsCommand
Deletes a caption track.
YoutubeDeleteChannelSectionsCommand
Deletes a channel section.
YoutubeDeleteCommentsCommand
YoutubeDeletePlaylistImagesCommand
Deletes a playlist image.
YoutubeDeletePlaylistItemsCommand
Deletes a playlist item.
YoutubeDeletePlaylistsCommand
Deletes a playlist.
YoutubeDeleteStreamCommand
Deletes a video stream.
YoutubeDeleteSubscriptionsCommand
Deletes a subscription.
YoutubeDeleteThirdPartyLinksCommand
Deletes a third-party link.
YoutubeDeleteVideosCommand
Deletes a YouTube video.
YoutubeDownloadCaptionsCommand
Downloads a caption track.
YoutubeGetRatingVideosCommand
Binds a YouTube broadcast to a stream or removes an existing binding between a broadcast and a stream. A broadcast can only be bound to one video stream, though a video stream may be bound to more than one broadcast.
YoutubeI18nLanguagesCommand
Command group for the i18nLanguages resource.
YoutubeI18nRegionsCommand
Command group for the i18nRegions resource.
YoutubeInsertBroadcastCommand
Creates a broadcast.
YoutubeInsertCaptionsCommand
Uploads a caption track.
YoutubeInsertChannelBannersCommand
Uploads a channel banner image to YouTube.
YoutubeInsertChannelSectionsCommand
Adds a channel section to the authenticated user's channel.
YoutubeInsertCommentsCommand
YoutubeInsertCommentThreadsCommand
YoutubeInsertPlaylistImagesCommand
Uploads a custom playlist image and associates it with the given playlist.
YoutubeInsertPlaylistItemsCommand
Adds a resource to a playlist.
YoutubeInsertPlaylistsCommand
Creates a broadcast.
YoutubeInsertStreamCommand
Creates a video stream. The stream enables you to send your video to YouTube, which can then broadcast the video to your audience.
YoutubeInsertSubscriptionsCommand
Adds a subscription for the authenticated user's channel.
YoutubeInsertThirdPartyLinksCommand
Posts a third-party link to a YouTube channel.
YoutubeInsertVideosCommand
Uploads a video to YouTube and optionally sets the video's metadata.
YoutubeListActivitiesCommand
Returns a list of channel activity events that match the request criteria.
YoutubeListBroadcastCommand
Returns a list of YouTube broadcasts that match the API request parameters.
YoutubeListByChannelIdCommentThreadsCommand
The channelId parameter instructs the API to return all comment threads associated with the specified channel.
YoutubeListByIdCommentsCommand
YoutubeListByIdCommentThreadsCommand
The id parameter specifies a comment thread ID for the resource that should be retrieved.
YoutubeListByIdsCommentsCommand
YoutubeListByIdsCommentThreadsCommand
The ids parameter specifies a list of comment thread IDs for the resources that should be retrieved.
YoutubeListByParentIdCommentsCommand
YoutubeListByVideoIdCommentThreadsCommand
YoutubeListCaptionsCommand
Returns a list of caption tracks that are associated with a specified video.
YoutubeListChannelsCommand
Returns a collection of zero or more channel resources that match the request criteria.
YoutubeListChannelSectionsCommand
Returns a list of channelSection resources that match the API request criteria.
YoutubeListCommentsCommand
Returns a list of comments that match the API request parameters.
YoutubeListCommentThreadsCommand
Returns a list of comment threads that match the API request parameters.
YoutubeListI18nLanguagesCommand
Returns a list of application languages that the YouTube website supports.
YoutubeListI18nRegionsCommand
Returns a list of content regions that the YouTube website supports.
YoutubeListMembersCommand
List members for a YouTube channel.
YoutubeListMembershipsLevelsCommand
List membership pricing levels available for the channel.
YoutubeListPlaylistImagesCommand
Returns a list of playlist images for the given playlist.
YoutubeListPlaylistItemsCommand
Returns a collection of playlist items that match the API request parameters.
YoutubeListPlaylistsCommand
Returns a collection of playlists that match the API request parameters. For example, you can retrieve all playlists that the authenticated user owns, or you can retrieve one or more playlists by their unique IDs.
YoutubeListSearchCommand
Returns a collection of search results that match the query parameters specified in the API request. By default, a search result set identifies matching video, channel, and playlist resources, but you can also configure queries to only retrieve a specific type of resource.
YoutubeListStreamCommand
Returns a list of video streams that match the API request parameters.
YoutubeListSubscriptionsCommand
Returns subscription resources that match the API request criteria.
YoutubeListThirdPartyLinksCommand
Returns a list of third-party links of the specified type.
YoutubeListVideoAbuseReportReasonsCommand
Retrieve a list of reasons for reporting abusive videos.
YoutubeListVideoCategoriesCommand
Returns a list of categories that can be associated with YouTube videos.
YoutubeListVideosCommand
Returns a list of videos that match the API request parameters.
YoutubeMembersCommand
Command group for managing YouTube channel members.
YoutubeMembershipsLevelsCommand
Command group for managing channel membership levels.
YoutubePlaylistImagesCommand
Command group for the playlistImages resource.
YoutubePlaylistItemsCommand
Command group for the playlistItems resource.
YoutubePlaylistsCommand
A playlist resource represents a YouTube playlist. A playlist is a collection of videos that can be viewed sequentially and shared with other users. By default, playlists are publicly visible to other users, but playlists can be public or private.
YoutubeRateVideosCommand
Add a like or dislike rating to a video or remove a rating from a video.
YoutubeSearchCommand
A search result contains information about a YouTube video, channel, or playlist that matches the search parameters specified in an API request. While a search result points to a uniquely identifiable resource, like a video, it does not have its own persistent data.
YoutubeSetModerationStatusCommentsCommand
YoutubeSetThumbnailsCommand
Uploads a custom video thumbnail to YouTube and sets it for a video.
YoutubeSetWatermarksCommand
Uploads a custom video thumbnail to YouTube and sets it for a video.
YoutubeStreamCommand
A liveStream resource contains information about the video stream that you are transmitting to YouTube. The stream provides the content that will be broadcast to YouTube users. Once created, a liveStream resource can be bound to one or more liveBroadcast resources.
YoutubeSubscriptionsCommand
A Subscription resource contains information about a YouTube user subscription. A subscription notifies a user when new videos are added to a channel or when another user takes one of several actions on YouTube, such as uploading a video, rating a video, or commenting on a video.
YoutubeThirdPartyLinksCommand
Command group for the thirdPartyLinks resource.
YoutubeThumbnailsCommand
A thumbnail resource identifies different thumbnail image sizes associated with a resource. Please note the following characteristics of thumbnail images:
YoutubeTransitionBroadcastCommand
Changes the status of a YouTube live broadcast and initiates any processes associated with the new status. For example, when you transition a broadcast's status to testing, YouTube starts to transmit video to that broadcast's monitor stream. Before calling this method, you should confirm that the value of the status.streamStatus property for the stream bound to your broadcast is active.
YoutubeUnsetWatermarksCommand
Deletes a channel's watermark image.
YoutubeUpdateBroadcastCommand
Updates a broadcast. For example, you could modify the broadcast settings defined in the liveBroadcast resource's contentDetails object.
YoutubeUpdateCaptionsCommand
Updates a caption track.
YoutubeUpdateChannelsCommand
Updates a channel's metadata. Note that this method currently only supports updates to the channel resource's brandingSettings, invideoPromotion, and localizations objects and their child properties.
YoutubeUpdateChannelSectionsCommand
Updates a channel section.
YoutubeUpdateCommentsCommand
YoutubeUpdatePlaylistImagesCommand
Replaces the image bytes for an existing playlist image.
YoutubeUpdatePlaylistItemsCommand
Modifies a playlist item.
YoutubeUpdatePlaylistsCommand
Modifies a playlist. For example, you could change a playlist's title, description, or privacy status.
YoutubeUpdateStreamCommand
Updates a video stream. If the properties that you want to change cannot be updated, then you need to create a new stream with the proper settings.
YoutubeUpdateThirdPartyLinksCommand
Updates an existing third-party link.
YoutubeUpdateVideosCommand
Updates a video's metadata.
YoutubeVersionCommand
Display the yt_cli package name and version information.
YoutubeVideoAbuseReportReasonsCommand
Command group for video abuse report reasons.
YoutubeVideoCategoriesCommand
A video resource represents a YouTube video.
YoutubeVideosCommand
A video resource represents a YouTube video.
YoutubeWatermarksCommand
A Watermarks resource identifies an image that displays during playbacks of a specified channel's videos. You can also specify a target channel to which the image will link as well as timing details that determine when the watermark appears during video playbacks and the length of time it is visible.
YtHelperCommand