YoutubeUpdateChannelSectionsCommand class
Updates a channel section.
- Inheritance
-
- Object
- Command<
void> - YtHelperCommand
- YoutubeUpdateChannelSectionsCommand
Constructors
Properties
- activities → Activities
-
no setterinherited
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- analytics → Analytics
-
no setterinherited
- argParser → ArgParser
-
The argument parser for this command.
no setterinherited
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- broadcast → Broadcast
-
no setterinherited
- captions → Captions
-
no setterinherited
- category → String
-
The command's category.
no setterinherited
- channelBanners → ChannelBanners
-
no setterinherited
- channels → Channels
-
no setterinherited
- channelSections → ChannelSections
-
no setterinherited
- chat → Chat
-
no setterinherited
- comments → Comments
-
no setterinherited
- commentThreads → CommentThreads
-
no setterinherited
- description → String
-
A description of this command, included in usage.
no setteroverride
- globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether or not this command should be hidden from help listings.
no setterinherited
- i18nLanguages → I18nLanguages
-
no setterinherited
- i18nRegions → I18nRegions
-
no setterinherited
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - liveStream → LiveStream
-
no setterinherited
- members → Members
-
no setterinherited
- membershipsLevels → MembershipsLevels
-
no setterinherited
- name → String
-
The name of this command.
no setteroverride
-
parent
→ Command<
void> ? -
The command's parent command, if this is a subcommand.
no setterinherited
- playlistImages → PlaylistImages
-
no setterinherited
- playlistItems → PlaylistItems
-
no setterinherited
- playlists → Playlists
-
no setterinherited
-
runner
→ CommandRunner<
void> ? -
The command runner for this command.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → Search
-
no setterinherited
-
subcommands
→ Map<
String, Command< void> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
- subscriptions → Subscriptions
-
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- thirdPartyLinks → ThirdPartyLinks
-
no setterinherited
- thumbnails → Thumbnails
-
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.no setterinherited - videoAbuseReportReasons → VideoAbuseReportReasons
-
no setterinherited
- videoCategories → VideoCategories
-
no setterinherited
- videos → Videos
-
no setterinherited
- watermarks → Watermarks
-
no setterinherited
Methods
-
addSubcommand(
Command< void> command) → void -
Adds
Commandas a subcommand of this.inherited -
close(
) → void -
inherited
-
initializeYt(
) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
run(
) → void -
Runs this command.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited